package schedframe.resources.computing.profiles.energy.airthroughput.ui;

import java.util.ArrayList;
import java.util.List;

import schedframe.Parameters;
import schedframe.resources.computing.ComputingResource;
import schedframe.resources.computing.profiles.energy.EnergyEvent;
import schedframe.resources.computing.profiles.energy.EnergyEventType;
import schedframe.resources.computing.profiles.energy.airthroughput.AirThroughputProfile;
import schedframe.resources.computing.profiles.energy.airthroughput.AirThroughputState;

public class DefaultAirThroughputInterface implements AirThroughputInterface{

	protected String currentAirThroughputState;
	protected AirThroughputProfile airThroughputProfile;
	protected ComputingResource resource;
	
	public DefaultAirThroughputInterface(ComputingResource resource, AirThroughputProfile airThroughputProfile){
		this.resource = resource;
		this.airThroughputProfile = airThroughputProfile;
	}
	
	public String getAirThroughputState() {
		return currentAirThroughputState;
	}

	public boolean setAirThroughputState(String state) {
		if(supportAirThroughputState(state)){
			currentAirThroughputState = state;
			
			//TO DO - notifications should be called for all resources starting form the lowest layer
			resource.handleEvent(new EnergyEvent(EnergyEventType.AIRFLOW_STATE_CHANGED, resource.getName()));

			return true;
		}
		return false;
	}

	public boolean supportAirThroughputState(String state) {
		for(AirThroughputState airFlowState: airThroughputProfile.getAirThroughputStates()){
			if(airFlowState.getName().equals(state)){
				return true;
			}
		}
		return false;
	}

	public List<AirThroughputState> getSupportedAirThroughputStates() throws NoSuchFieldException {
		List<AirThroughputState> airThroughputStates = new ArrayList<AirThroughputState>();
		for(AirThroughputState airFlowState: airThroughputProfile.getAirThroughputStates()){
			airThroughputStates.add(airFlowState);
		}
		return airThroughputStates;
	}

	public double getPowerConsumption(String state) throws NoSuchFieldException {
		double powerConsumption = 0;
		if(supportAirThroughputState(state)){
			for(AirThroughputState airFlowState: airThroughputProfile.getAirThroughputStates()){
				if(airFlowState.getName().equals(state)){
					powerConsumption = airFlowState.getPowerUsage();
					break;
				}
			}
		}
		return powerConsumption;
	}

	public Parameters getParameters() {
		return airThroughputProfile.getParameters();
	}

}
